@@ -18,7 +18,6 @@ from __future__ import absolute_import
 
 import os
 import warnings
-from nansat.warnings import NansatFutureWarning
 import logging
 from dateutil.parser import parse
 
@@ -33,7 +32,6 @@ try:
 except ImportError:
     BASEMAP_LIB_IS_INSTALLED = False
     MATPLOTLIB_IS_INSTALLED = False
-
 else:
     BASEMAP_LIB_IS_INSTALLED = True
     MATPLOTLIB_IS_INSTALLED = True
@@ -46,57 +44,6 @@ except:
     from osgeo import gdal, ogr, osr
 gdal.UseExceptions()
 
-EXCEPTION_WARNING = (
-                             'Use Nansat(filename).')
-
-class OptionError(Exception):
-    def __init__(self, *args, **kwargs):
-        warnings.warn(
-            'nansat.tools.OptionError will be disabled in Nansat 1.1. Use ValueError instead.',
-            NansatFutureWarning)
-
-
-class ProjectionError(Exception):
-    def __init__(self, *args, **kwargs):
-        warnings.warn(
-            'nansat.tools.ProjectionError will be disabled in Nansat 1.1. Use ' \
-                'nansat.exceptions.NansatProjectionError instead.',
-            NansatFutureWarning)
-
-
-class GDALError(Exception):
-    def __init__(self, *args, **kwargs):
-        warnings.warn(
-            'nansat.tools.GDALError will be disabled in Nansat 1.1. Use ' \
-                'nansat.exceptions.NansatGDALError instead.',
-            NansatFutureWarning)
-
-
-class NansatReadError(Exception):
-    def __init__(self, *args, **kwargs):
-        warnings.warn(
-            'nansat.tools.NansatReadError will be disabled in Nansat 1.1. Use ' \
-                'nansat.exceptions.NansatReadError instead.',
-        NansatFutureWarning)
-
-
-class GeolocationError(Exception):
-    def __init__(self, *args, **kwargs):
-        warnings.warn(
-            'nansat.tools.GeolocationError will be disabled in Nansat 1.1. Use ' \
-                'nansat.exceptions.NansatGeolocationError instead.',
-            NansatFutureWarning)
-
-
-class WrongMapperError(Exception):
-    def __init__(self, *args, **kwargs):
-        warnings.warn(
-            'nansat.tools.WrongMapperError will be disabled in Nansat 1.1. Use ' \
-                'nansat.exceptions.WrongMapperError instead.',
-        NansatFutureWarning)
-
-
-
 def remove_keys(dict, keys):
     if keys is None:
         keys = []
